package Locale::CLDR::Mua::Any v0.25.0;
# This file auto generated
#	on Tue 22 Apr 12:00:13 am GMT

use v5.18;
use mro 'c3';

use Moose;

extends('Locale::CLDR::Mua');

no Moose;
__PACKAGE__->meta->make_immutable;
